@@ -72,6 +72,49 @@ class IssueSet(DataClassJSONMixin):
     issues: Issue
 
 
+@dataclass
+class IssueData(DataClassJSONMixin):
+    id: str
+    title: str
+    severity: str
+    url: str
+    exploitMaturity: str
+    description: Optional[str] = None
+    identifiers: Optional[Any] = None
+    credit: Optional[str] = None
+    semver: Optional[Any] = None
+    publicationTime: Optional[str] = None
+    disclosureTime: Optional[str] = None
+    CVSSv3: Optional[str] = None
+    cvssScore: Optional[str] = None
+    language: Optional[str] = None
+    patches: Optional[Any] = None
+    nearestFixedInVersion: Optional[str] = None
+
+
+@dataclass
+class AggregatedIssue(DataClassJSONMixin):
+    id: str
+    issueType: str
+    pkgName: str
+    pkgVersions: List[str]
+    issueData: IssueData
+    isPatched: bool
+    isIgnored: bool
+    introducedThrough: Optional[List[Any]] = None
+    ignoreReasons: Optional[List[Any]] = None
+    fixInfo: Optional[Any] = None
+    # Not mentioned in schema but returned
+    # https://snyk.docs.apiary.io/#reference/projects/aggregated-project-issues/list-all-aggregated-issues
+    priorityScore: Optional[int] = None
+    priority: Optional[Any] = None
+
+
+@dataclass
+class IssueSetAggregated(DataClassJSONMixin):
+    issues: List[AggregatedIssue]
+
+
 @dataclass
 class OrganizationGroup(DataClassJSONMixin):
     name: str
@@ -493,6 +536,10 @@ class Project(DataClassJSONMixin):
     def issueset(self) -> Manager:
         return Manager.factory(IssueSet, self.organization.client, self)
 
+    @property
+    def issueset_aggregated(self) -> Manager:
+        return Manager.factory(IssueSetAggregated, self.organization.client, self)
+
     @property
     def vulnerabilities(self) -> List[Vulnerability]:
         return self.issueset.all().issues.vulnerabilities
